//////////////////////////////////////////////////////////////////////////////
//
// "Embedded C Programming: Techniques and Applications of C and PIC MCUs"
// by Mark Siegusmund
//
// Exercise 20-1 #3
//
// Determines the capacitance of a capacitor and displays the result in
// microFarads with one decimal point.
//
//////////////////////////////////////////////////////////////////////////////

#include <e3.h>

#use timer(timer=1, tick=1ms, bits=32, ISR)

#define RC_THRESH (0.37 * 256)  //37% of 5V

#define R   100000   //ohms

void main(void)   
{
   int32 startTime, endTime, time;
   float uF;
   
   setup_adc_ports(sAN10); //PIN_B4
   setup_adc(ADC_CLOCK_INTERNAL | ADC_TAD_MUL_2);
   set_adc_channel(10);
   
   output_high(PIN_B4);
   delay_ms(2000);
   output_float(PIN_B4);
   
   startTime = get_ticks();
   
   while(read_adc() > RC_THRESH) { }
   
   endTime = get_ticks();
   
   time = endTime - startTime;
   
   uF = (float)time * ((float)1000000.0 / (R * TICKS_PER_SECOND));
   
   printf("uF = %f  (time = %lu ms)\r\n", uF, (time * 1000)/TICKS_PER_SECOND);
   
   for(;;);
}


